import { z } from "zod";
export const DnDConfigSchema = z.object({
    active: z.boolean(),
    selectionBorderColor: z.string().optional(),
    selectionBorderSize: z.number().min(1).optional(),
    resizeHandleSize: z.number().min(4).optional(),
    resizeHandleBorderSize: z.number().min(1).optional(),
    resizeHandleBorderColor: z.string().optional(),
    resizeHandleBackgroundColor: z.string().optional(),
    sanppingThreshold: z.number().optional(),
    snapPositionsX: z.array(z.number()).optional(),
    snapPositionsY: z.array(z.number()).optional(),
    step: z.number().optional(),
});
export const DragAndDropItemSchema = z.object({
    id: z.union([z.number(), z.string()]),
    from: z.number(),
    durationInFrames: z.number(),
    unit: z.enum(["px", "%"]),
    top: z.number(),
    left: z.number(),
    width: z.number(),
    height: z.number(),
    enforceRatio: z.tuple([z.number(), z.number()]).optional(),
    zIndex: z.number().optional(),
    color: z.string(),
    isDragging: z.boolean(),
});
export const DnDPropsSchema = z.object({
    config: DnDConfigSchema,
    selectedItem: z.union([z.number(), z.string()]).nullable(),
    setSelectedItem: z
        .function()
        .args(z.union([
        z.union([z.number(), z.string()]).nullable(),
        z
            .function()
            .args(z.union([z.number(), z.string()]).nullable())
            .returns(z.union([z.number(), z.string()]).nullable()),
    ]))
        .returns(z.void()),
    items: z.array(DragAndDropItemSchema),
    insertItems: z
        .function()
        .args(z.array(DragAndDropItemSchema))
        .returns(z.void()),
    changeItem: z
        .function()
        .args(z.union([z.number(), z.string()]), z.function().args(DragAndDropItemSchema).returns(DragAndDropItemSchema))
        .returns(z.void()),
});
//# sourceMappingURL=type.js.map